import { Button } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React from 'react'
import './ecogestureSelectionModal.scss'

interface EcogestureSelectionModalProps {
  open: boolean
  handleCloseClick: () => void
}

const EcogestureSelectionModal = ({
  open,
  handleCloseClick,
}: EcogestureSelectionModalProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('ecogesture_selection.accessibility.window_title')}
      </div>
      <StyledIconButton
        icon={CloseIcon}
        onClick={handleCloseClick}
        aria-label={t('ecogesture_selection.accessibility.button_close')}
        className="modal-paper-close-button"
      />
      <div className="eg-selection-modal">
        <div className="title text-20-bold">
          {t('ecogesture_selection.selectionModal.title')}
        </div>
        <div className="text text-16-normal">
          {t('ecogesture_selection.selectionModal.text')}
        </div>
        <Button onClick={handleCloseClick} className="btnPrimary">
          {t('ecogesture_selection.selectionModal.button_close')}
        </Button>
      </div>
    </Dialog>
  )
}

export default EcogestureSelectionModal
