import { Button } from '@material-ui/core'
import * as Sentry from '@sentry/react'
import EcolyoGlowIcon from 'assets/icons/ico/ecolyo-glow.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import Loader from 'components/Loader/Loader'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React, { useCallback, useEffect, useMemo, useState } from 'react'
import ProfileService from 'services/profile.service'
import './unsubscribe.scss'

const Unsubscribe = () => {
  const { t } = useI18n()
  const client = useClient()

  const [isLoading, setIsLoading] = useState(true)
  const [status, setStatus] = useState<
    'subscribed' | 'error' | 'unsubscribed'
  >()

  const profileService = useMemo(() => new ProfileService(client), [client])

  const updateSubscription = useCallback(
    (value: boolean) => {
      setIsLoading(true)

      profileService
        .updateProfile({ sendAnalysisNotification: value })
        .then(() => {
          setStatus(value ? 'subscribed' : 'unsubscribed')
        })
        .catch(err => {
          setStatus('error')
          console.error(err)
          Sentry.captureException('Failed to unsubscribe')
        })
        .finally(() => {
          setIsLoading(false)
        })
    },
    [profileService]
  )

  useEffect(() => {
    updateSubscription(false)
  }, [updateSubscription])

  return (
    <div className="unsubscribe-container">
      {isLoading && <Loader />}
      {!isLoading && (
        <>
          <StyledIcon icon={EcolyoGlowIcon} size={180} />
          <div className="text-20-bold head">{t(`unsubscribe.${status}`)}</div>
          {status === 'unsubscribed' && (
            <div className="text-16-normal question">
              {t('unsubscribe.content')}
            </div>
          )}
          {status !== 'subscribed' && status !== 'error' && (
            <Button
              className="btnPrimary"
              onClick={() => updateSubscription(true)}
            >
              {t('unsubscribe.button_subscribe')}
            </Button>
          )}
          <Button
            className="btnText"
            onClick={() => window.location.replace('/')}
          >
            {t('unsubscribe.button_home')}
          </Button>
        </>
      )}
    </div>
  )
}

export default Unsubscribe
