import { AccountEGLData } from 'models'
import { accountsData } from 'tests/__mocks__/accountsData.mock'
import mockClient from 'tests/__mocks__/client.mock'
import { konnectorsData } from 'tests/__mocks__/konnectorsData.mock'
import { triggersData } from 'tests/__mocks__/triggersData.mock'
import ConnectionService from './connection.service'

const mockGetKonnector = jest.fn()
jest.mock('./konnector.service', () => {
  return jest.fn(() => ({
    getKonnector: mockGetKonnector,
  }))
})

const mockCreateAccount = jest.fn()
jest.mock('./account.service', () => {
  return jest.fn(() => ({
    createAccount: mockCreateAccount,
  }))
})

const mockCreateTrigger = jest.fn()
jest.mock('./triggers.service', () => {
  return jest.fn(() => ({
    createTrigger: mockCreateTrigger,
  }))
})

const mockEGLAuthData: AccountEGLData = {
  login: 'login',
  password: 'password',
}

describe('Connection service', () => {
  const connectionService = new ConnectionService(mockClient)

  describe('connectNewUser method', () => {
    it('should return created Trigger', async () => {
      mockGetKonnector.mockResolvedValueOnce(konnectorsData[0])
      mockCreateAccount.mockResolvedValueOnce(accountsData[0])
      mockCreateTrigger.mockResolvedValueOnce(triggersData[0])
      const mockResult = { account: accountsData[0], trigger: triggersData[0] }
      const result = await connectionService.connectNewUser(
        konnectorsData[0]._id,
        mockEGLAuthData
      )
      expect(result).toEqual(mockResult)
    })

    it('should throw error when konnector is not found', async () => {
      let error
      try {
        await connectionService.connectNewUser(
          konnectorsData[0]._id,
          mockEGLAuthData
        )
      } catch (err) {
        error = err
      }
      expect(error).toEqual(
        new Error(`Could not find konnector for ${konnectorsData[0]._id}`)
      )
    })

    it('should throw error when account is not created', async () => {
      mockGetKonnector.mockResolvedValueOnce(konnectorsData[0])
      let error
      try {
        await connectionService.connectNewUser(
          konnectorsData[0]._id,
          mockEGLAuthData
        )
      } catch (err) {
        error = err
      }
      expect(error).toEqual(new Error(`Error during account creation`))
    })

    it('should throw error when trigger is not created', async () => {
      mockGetKonnector.mockResolvedValueOnce(konnectorsData[0])
      mockCreateAccount.mockResolvedValueOnce(accountsData[0])
      let error
      try {
        await connectionService.connectNewUser(
          konnectorsData[0]._id,
          mockEGLAuthData
        )
      } catch (err) {
        error = err
      }
      expect(error).toEqual(new Error(`Error during trigger creation`))
    })
  })
})
