import { Client, Q, QueryResult } from 'cozy-client'
import { KONNECTORS_DOCTYPE } from 'doctypes'
import { Account, Konnector, TriggerState } from 'models'
import TriggerService from 'services/triggers.service'

export default class KonnectorService {
  private _client: Client

  constructor(_client: Client) {
    this._client = _client
  }

  public async getKonnector(id: string): Promise<Konnector | null> {
    const query = Q(KONNECTORS_DOCTYPE).where({
      _id: KONNECTORS_DOCTYPE + '/' + id,
    })
    const { data: konnector }: QueryResult<Konnector[]> =
      await this._client.query(query)
    return konnector[0] ? konnector[0] : null
  }

  public async getKonnectorLastState(
    konnector: Konnector,
    account: Account
  ): Promise<TriggerState | null> {
    const triggerService = new TriggerService(this._client)
    const trigger = await triggerService.getTrigger(account, konnector)
    if (trigger) {
      const triggerState = await triggerService.fetchTriggerState(trigger)
      return triggerState
    }
    return null
  }

  public async createIndexKonnector() {
    const query = Q(KONNECTORS_DOCTYPE).where({ _id: 'index' }).limitBy(1)
    const { data: result }: QueryResult<[]> = await this._client.query(query)
    return result
  }
}
