import { PayloadAction, createAsyncThunk, createSlice } from '@reduxjs/toolkit'
import { Client } from 'cozy-client'
import { PROFILEECOGESTURE_DOCTYPE } from 'doctypes'
import { IndividualOrCollective, WarmingType } from 'enums'
import { ProfileEcogesture } from 'models'
import { AppDispatch, AppState } from 'store/store'

const initialState: ProfileEcogesture = {
  heating: IndividualOrCollective.INDIVIDUAL,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  equipments: [],
}

export const profileEcogestureSlice = createSlice({
  name: 'profileEcogesture',
  initialState,
  reducers: {
    setProfileEcogesture: (state, action: PayloadAction<ProfileEcogesture>) => {
      Object.assign(state, action.payload)
    },
  },
  extraReducers: builder => {
    builder.addCase(newProfileEcogestureEntry.fulfilled, (state, action) => {
      Object.assign(state, action.payload)
    })
  },
})

export const { setProfileEcogesture } = profileEcogestureSlice.actions

/**
 * Thunk creating a new profile ecogesture in couch DB.
 * Then dispatch it to the app
 */
export const newProfileEcogestureEntry = createAsyncThunk<
  ProfileEcogesture | void,
  Partial<ProfileEcogesture>,
  { dispatch: AppDispatch; state: AppState; extra: { client: Client } }
>('profileEcogesture/newProfileEcogesture', async (updates, thunkAPI) => {
  const client = thunkAPI.extra.client
  const { data: newProfileEcogesture } = await client.create(
    PROFILEECOGESTURE_DOCTYPE,
    updates
  )
  if (newProfileEcogesture) {
    return newProfileEcogesture
  }
})
